@@ -386,15 +386,22 @@ class Translator:
             # TODO: use default_assembly_name here
             if ns.startswith("GRC") and namespace is None:
                 continue
+
+            if not (any(a.startswith(pfx) for pfx in ("NM", "NP", "NC", "NG"))):
+                continue
+
             var.ac = a
 
-            if not namespace.startswith("GRC"):
-                # if the namespace is GRC, can't normalize, since hgvs can't deal with it
-                hgvs_tools = self._get_hgvs_tools()
-                parsed = hgvs_tools.parse(str(var))
-                var = hgvs_tools.normalize(parsed)
+            try:
+                if not namespace.startswith("GRC"):
+                    # if the namespace is GRC, can't normalize, since hgvs can't deal with it
+                    hgvs_tools = self._get_hgvs_tools()
+                    parsed = hgvs_tools.parse(str(var))
+                    var = hgvs_tools.normalize(parsed)
 
-            hgvs_exprs += [str(var)]
+                hgvs_exprs += [str(var)]
+            except hgvs.exceptions.HGVSDataNotAvailableError:
+                _logger.warning(f"No data found for accession {a}")
 
         return list(set(hgvs_exprs))
 
@@ -426,8 +433,8 @@ class Translator:
         aliases = self.data_proxy.translate_sequence_identifier(sequence_id, namespace)
         aliases = [a.split(":")[1] for a in aliases]
 
-        start = vo.location.interval.start
-        end = vo.location.interval.end
+        start = vo.location.interval.start.value
+        end = vo.location.interval.end.value
         spdi_tail = f":{start}:{end-start}:{vo.state.sequence}"
         spdis = [a + spdi_tail for a in aliases]
         return spdis
